#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;

#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Candle Stick Pattern Recognittion
    /// </summary>

	 
    [Description("Inside Bar Indicator")]
    public class InsideBar : Indicator
    {
        #region Variables
        // Wizard generated variables

			private DataSeries insidebar;
			private Color upcolor;
			private bool soundon;
			private double range1 =0;
			private double range2 =0;
			private double range3 =0;
			private double range4 =0;
		
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= false;
			upcolor = Color.Yellow;
			insidebar			=	new DataSeries(this);
			soundon = false;
			
			
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar < 4) return;
			
			range1 = Math.Abs(Close[0]-Open[0]);
			range2 = Math.Abs(Close[1]-Open[1]);
			range3 = Math.Abs(Close[2]-Open[2]);
			range4 = Math.Abs(Close[3]-Open[3]);
		// Check for InsideBar pattern
				
			if(High[0] < High[1] && Low[0] > Low[1]
				&& range4 < range3
				&& range4 < range2
				&& range4 < range1
				)	
				
			{
				BarColor = upcolor;
				insidebar.Set(1);
				if(soundon)
					{
						if (!Historical)
							PlaySound(@"C:\Program Files\NinjaTrader 6.5\sounds\Alert4.wav");
					}
			}
			else
				insidebar.Set(0);
        }

        #region Properties
			[CategoryAttribute("Plots")]
			[DescriptionAttribute("Inside BAr Color")]
			[XmlIgnoreAttribute()]
			[NinjaTrader.Gui.Design.DisplayNameAttribute("Inside BAr Color")]
			public Color UpColor

			{
				get { return upcolor; }
				set { upcolor = value; }
			}

			[BrowsableAttribute(false)]
			public string UpColorSerialize
			
	
			{
			get { return NinjaTrader.Gui.Design.SerializableColor.ToString(upcolor); }
			set { upcolor = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
			}
		
		[Browsable(false)]
        [XmlIgnore()]
        public DataSeries Insidebar
        {
            get 
           { 
                Update();
                return insidebar;
			 
           }
        }
		
			[NinjaTrader.Gui.Design.DisplayNameAttribute("Sound on?")]
			[DescriptionAttribute("Sound on?")]
			[CategoryAttribute("Parameters")]
			public bool SoundOn
				
			{
				get { return soundon ; }
				set { soundon  =  value; }
			}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private InsideBar[] cacheInsideBar = null;

        private static InsideBar checkInsideBar = new InsideBar();

        /// <summary>
        /// Inside Bar Indicator
        /// </summary>
        /// <returns></returns>
        public InsideBar InsideBar()
        {
            return InsideBar(Input);
        }

        /// <summary>
        /// Inside Bar Indicator
        /// </summary>
        /// <returns></returns>
        public InsideBar InsideBar(Data.IDataSeries input)
        {

            if (cacheInsideBar != null)
                for (int idx = 0; idx < cacheInsideBar.Length; idx++)
                    if (cacheInsideBar[idx].EqualsInput(input))
                        return cacheInsideBar[idx];

            InsideBar indicator = new InsideBar();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.SetUp();

            InsideBar[] tmp = new InsideBar[cacheInsideBar == null ? 1 : cacheInsideBar.Length + 1];
            if (cacheInsideBar != null)
                cacheInsideBar.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheInsideBar = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Inside Bar Indicator
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.InsideBar InsideBar()
        {
            return _indicator.InsideBar(Input);
        }

        /// <summary>
        /// Inside Bar Indicator
        /// </summary>
        /// <returns></returns>
        public Indicator.InsideBar InsideBar(Data.IDataSeries input)
        {
            return _indicator.InsideBar(input);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Inside Bar Indicator
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.InsideBar InsideBar()
        {
            return _indicator.InsideBar(Input);
        }

        /// <summary>
        /// Inside Bar Indicator
        /// </summary>
        /// <returns></returns>
        public Indicator.InsideBar InsideBar(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.InsideBar(input);
        }

    }
}
#endregion
